#[derive(ManualType)]Expand description
This is a no-op marker trait that allows the migration tool to know when a user has manually implemented a type.
This is useful for having data that’s a string in the database, but a strum::EnumString in code.